Attribute VB_Name = "DELTATV"
'  Copyright (c) 2003 Intelligent Resources Inc. All rights reserved.
'  An image map is created for DELTATV.CSV, with kriging gridding method. A
'  contour map is generated as well, and both maps are then combined into one
'  map via Map|Overlay Maps.

Option Explicit

Dim SurferApp As Object
Dim convertInchToCentimeter As Boolean
Dim Doc As Object
Dim Plotwindow As Object

Dim ImageMapFrame As Object
Dim Overlays As Object
Dim ImageMap As Object
Dim ColorMap As Object

Dim ContourMapFrame As Object
Dim ContourMap As Object
Dim ContourLevels As Object
Dim ContourLevel As Object
Dim LevelLine As Object

Dim ShotPostMapFrame As Object
Dim ShotPostMap As Object

Dim OverlayMapFrame As Object

Dim retValue As Boolean
Dim griddedAlready As Boolean
Dim isRayTrial As Boolean
Dim isSrfTrial As Boolean
Dim postShotPoints As Boolean
Dim labelShotPoints As Boolean
Dim postReceivers As Boolean
Dim labelReceivers As Boolean
Dim GSCenteredFont As Boolean
Dim debugScript As Boolean
Dim fineGrid As Boolean

Dim rowCount As Integer
Dim colCount As Integer

Dim userPlotLimits As Boolean
Dim minX As Double
Dim maxX As Double
Dim minY As Double
Dim maxY As Double
Dim trunc_minZ As Integer
Dim trunc_maxZ As Integer
Dim maxZ_Contour As Integer
Dim zContour_Interval As Integer
Dim proportionalXYScaling As Boolean
Dim xScaleLength As Double
Dim yScaleLength As Double

Dim Data As String
Dim Grid As String
Dim BlankFile As String
Dim SrfFile As String
Dim End_FlagFile As String
Dim Rayfract_AppTitle As String
Dim GriddingFile As String
Dim ShotDataFile As String
Dim gotGriddingFile As Boolean
Dim griddingMethod As Integer
Dim gridAlgorithm As Integer
Dim contourGrid As Boolean
Dim boreholeSurvey As Boolean
Dim PlotTitle As String
Dim horizontalHole As Boolean
Dim yTopCoord As Double
Dim verticalPlotTitle As Boolean


Sub Read_StringParam_From_ParFile ( stringRead As String )

    Dim parLine As String
    Dim pathStart As Integer

    Line Input #1, parLine

    pathStart = InStr(parLine, ": ") + 2
    stringRead = Mid(parLine, pathStart)

End Sub

Sub Read_DoubleParam_From_ParFile ( doubleRead As Double )

    Dim parLine As String
    Dim valueStart As Integer

    Line Input #1, parLine
    valueStart = InStrRev(parLine, " ") + 1
    parLine = Mid(parLine, valueStart)
    doubleRead = Val(parLine)

End Sub

Sub Read_Optional_DoubleParam_From_ParFile ( lineTag As String, _
    doubleRead As Double )

    Dim parLine As String
    Dim valueStart As Integer
    Dim filePos As Long

    filePos = Seek(1)
    Line Input #1, parLine

    If InStr(parLine, lineTag) Then
        valueStart = InStrRev(parLine, " ") + 1
        parLine = Mid(parLine, valueStart)
        doubleRead = Val(parLine)
    Else
        doubleRead = 0.0
        Seek #1, filePos
    End If

End Sub

Sub Read_IntParam_From_ParFile ( intRead As Integer )

    Dim value As Double

    Read_DoubleParam_From_ParFile(value)

    intRead = value
End Sub

Sub Read_Optional_IntParam_From_ParFile ( lineTag As String, _
    intRead As Integer )

    Dim value As Double

    Read_Optional_DoubleParam_From_ParFile lineTag, value

    intRead = value
End Sub

Sub Read_Boolean_From_ParFile( boolRead As Boolean)
    Dim boolFlag As Integer

    Read_IntParam_From_ParFile(boolFlag)
    boolRead = ( boolFlag = 1 )
End Sub

Sub Read_Optional_Boolean_From_ParFile( lineTag As String, _
    boolRead As Boolean)

    Dim boolFlag As Integer

    Read_Optional_IntParam_From_ParFile lineTag, boolFlag
    boolRead = ( boolFlag = 1 )
End Sub


Sub Init_Flags_From_ParFile

    Dim griddedFlag As Integer
    Dim trialFlag As Integer
    Dim isConstVelocity As Integer
    Dim isBoreholeSurvey As Integer

    Read_IntParam_From_ParFile(griddedFlag)
    griddedAlready = ( griddedFlag = 1 )

    Read_IntParam_From_ParFile(isConstVelocity)
    contourGrid = ( isConstVelocity = 0 )

    Read_IntParam_From_ParFile(isBoreholeSurvey)
    boreholeSurvey = ( isBoreholeSurvey = 1 )

    Read_IntParam_From_ParFile(trialFlag)
    isRayTrial = ( trialFlag = 1 )

    Debug.Print "Gridded already : "; griddedAlready
    Debug.Print "Constant velocity grid : "; isConstVelocity
    Debug.Print "Contour grid data      : "; contourGrid
    Debug.Print "Is borehole survey     : "; boreholeSurvey
    Debug.Print "isRayTrial : "; isRayTrial
    Debug.Print ""

End Sub

Sub Init_ColAndRowCount_From_ParFile
    Dim cols As Integer
    Dim rows As Integer

    Read_IntParam_From_ParFile(cols)

    Read_IntParam_From_ParFile(rows)

    If ( fineGrid ) Then
       colCount = cols
       rowCount = rows
    End If

    Debug.Print "colCount : "; colCount
    Debug.Print "rowCount : "; rowCount

End Sub

Sub Init_XYZ_Range_And_ZContour_And_ScaleLengths_From_ParFile

    Read_Boolean_From_ParFile(userPlotLimits)
    Read_DoubleParam_From_ParFile(minX)
    Read_DoubleParam_From_ParFile(maxX)
    Read_DoubleParam_From_ParFile(minY)
    Read_DoubleParam_From_ParFile(maxY)
    Read_IntParam_From_ParFile(trunc_minZ)
    Read_IntParam_From_ParFile(trunc_maxZ)

    Read_IntParam_From_ParFile(zContour_Interval)
    Read_Boolean_From_ParFile(proportionalXYScaling)
    Read_DoubleParam_From_ParFile(xScaleLength)
    Read_DoubleParam_From_ParFile(yScaleLength)

    Debug.Print "User plot limits   : "; userPlotLimits
    Debug.Print "minimum offset     : "; minX
    Debug.Print "maximum offset     : "; maxX
    Debug.Print "minimum elevation  : "; minY
    Debug.Print "maximum elevation  : "; maxY
    Debug.Print "truncated min. Z   : "; trunc_minZ
    Debug.Print "truncated max. Z   : "; trunc_maxZ
    Debug.Print "Z contour interval : "; zContour_Interval
    Debug.Print "Proportional XY scaling : "; proportionalXYScaling
    Debug.Print "X scale length [in]: "; xScaleLength
    Debug.Print "Y Scale length [in]: "; yScaleLength

End Sub

Sub Init_ShotPointPosting_From_ParFile

    Read_Boolean_From_ParFile(postShotPoints)
    Read_Boolean_From_ParFile(labelShotPoints)
    Read_Boolean_From_ParFile(postReceivers)
    Read_Boolean_From_ParFile(labelReceivers)
    Read_Optional_Boolean_From_ParFile "GS CENTERED font", GSCenteredFont

    Debug.Print "Post shot points : "; postShotPoints
    Debug.Print "Label shot points : "; labelShotPoints
    Debug.Print "Post receiver stations : "; postReceivers
    Debug.Print "Label receiver stations : "; labelReceivers
    Debug.Print "GS CENTERED font : "; GSCenteredFont

End Sub

Sub Init_PlotTitle_From_ParFile

    Read_StringParam_From_ParFile(PlotTitle)

    Read_Boolean_From_ParFile(horizontalHole)
    Read_Boolean_From_ParFile(verticalPlotTitle)

    Debug.Print "Plot title      : "; PlotTitle
    Debug.Print "Horizontal hole : "; horizontalHole
    Debug.Print "Vertical title  : "; verticalPlotTitle
    Debug.Print ""

End Sub


Sub Init_Vars_From_ParFile

    If debugScript Then
        Open "D:\RAY\DAT\AUTODLTA.PAR" For Input As #1
    Else
        Open "AUTODLTA.PAR" For Input As #1
    End If

    Read_StringParam_From_ParFile(Data)
    Debug.Print "Data : "; Data

    Init_Flags_From_ParFile

    Read_StringParam_From_ParFile(BlankFile)

    Init_ColAndRowCount_From_ParFile

    Init_XYZ_Range_And_ZContour_And_ScaleLengths_From_ParFile

    Read_StringParam_From_ParFile(Rayfract_AppTitle)

    Init_ShotPointPosting_From_ParFile

    Init_PlotTitle_From_ParFile

    Close #1

End Sub

Sub Init_GriddingMethod_FromFile

    If debugScript Then
        GriddingFile = "D:\RAY\DAT\GRIDDING.PAR"
    Else
        GriddingFile = "GRIDDING.PAR"
    End If

    Dim FileOnDisk As String
    FileOnDisk = Dir$(GriddingFile)
    gotGriddingFile = ( Len(FileOnDisk) > 0 )
    Debug.Print "Got gridding method file : "; gotGriddingFile

    If gotGriddingFile Then
        Open GriddingFile For Input As #1
        Read_IntParam_From_ParFile(griddingMethod)
        Close #1
    End If

    Debug.Print "Gridding method          : "; griddingMethod
End Sub

Sub Init_GridAlgorithm_ForMethod
    Select Case griddingMethod
    Case Is < 1, Is > 5
        Debug.Print "Invalid gridding method !"
        gridAlgorithm = srfKriging
    Case 1
        gridAlgorithm = srfTriangulation
    Case 2
        gridAlgorithm = srfKriging
    Case 3
        gridAlgorithm = srfMinCurvature
    Case 4
        gridAlgorithm = srfNaturalNeighbor
    Case 5
        gridAlgorithm = srfNearestNeighbor
    End Select

    Debug.Print "Surfer algorithm         : "; gridAlgorithm
    Debug.Print
    Debug.Print "Please wait a few seconds, for Surfer..."
End Sub



Sub Init_FileNames_From_Data

    Dim extensionStart As Integer
    Dim directoryEnd As Integer

    extensionStart = InStrRev(Data, ".")
    Grid = Left(Data, extensionStart) + "GRD"
    SrfFile = Left(Data, extensionStart) + "SRF"
    End_FlagFile = Left(Data, extensionStart) + "OK"
    directoryEnd = InStrRev(Data, "\")
    ShotDataFile = Left(Data, directoryEnd) + "SHOTMAP.TXT"

    Debug.Print "Grid : "; Grid
    Debug.Print "SrfFile : "; SrfFile
    Debug.Print "BlankFile : "; BlankFile
    Debug.Print "End_FlagFile : "; End_FlagFile
    Debug.Print "ShotDataFile : "; ShotDataFile
    Debug.Print ""

End Sub

Sub Init_Global_Vars
    isSrfTrial = True
    fineGrid   = True

    If fineGrid Then ' leave as initialized in Init_ColAndRowCount...
    Else
        colCount = 100
        rowCount = 28
    End If

    griddingMethod = 2 'kriging per default
    gridAlgorithm  = srfKriging
    contourGrid = True
    boreholeSurvey = False
    horizontalHole = False
    verticalPlotTitle = False
End Sub

Sub Check_Surfer_Version
    Dim demoString_Start As Integer
    Dim caption As String
    Dim version As String

    caption = SurferApp.Caption
    demoString_Start = InStr(caption, "Demo")
    isSrfTrial = demoString_Start > 0

    Debug.Print "Surfer main window title : "; caption
    Debug.Print "Surfer application name : "; SurferApp.Name
    Debug.Print "Surfer version : "; SurferApp.Version
    Debug.Print "isSrfTrial : "; isSrfTrial

    version = "Surfer version nr. is " + SurferApp.Version
    Open "AUTODLTA.RUN" For Output As #1
    Write #1, version
    Close #1

End Sub

Sub Init_Doc_And_Plotwindow_Vars

    Set Doc = SurferApp.Documents.Add
    Set Plotwindow = Doc.Windows(1)

    Plotwindow.AutoRedraw = False

    ' Need to first open at least one window so main title _
    ' contains "Demo" string, for free Demo version
    Check_Surfer_Version

End Sub

Sub Convert_Inch_To_Centimeter ( value As Double )

    If convertInchToCentimeter Then
        value = value * 2.54
    End If

End Sub

Sub Detect_Surfer_PageUnits

    Debug.Print ""
    If SurferApp.PageUnits = srfUnitsInch Then
        convertInchToCentimeter = False
    ElseIf SurferApp.PageUnits = srfUnitsCentimeter Then
        convertInchToCentimeter = True
    Else
        convertInchToCentimeter = False
        Debug.Print "SurferApp.PageUnit has invalid value !"
    End If
    Debug.Print "convertInchToCentimeter : "; convertInchToCentimeter
    Debug.Print ""
End Sub

Sub Get_Surfer_Instance()
    'Get existing Surfer instance, or create a new one if none exists
    On Error Resume Next 'Turn off error reporting
    Set SurferApp = GetObject(,"Surfer.Application")
    If Err.Number<>0 Then
        Set SurferApp = CreateObject("Surfer.Application")
    End If
    On Error GoTo 0 'Turn back on error reporting

    SurferApp.Visible = True
    SurferApp.WindowState = srfWindowStateMaximized
    SurferApp.ScreenUpdating = True

    Detect_Surfer_PageUnits

    Init_Doc_And_Plotwindow_Vars

End Sub

Sub CreateGrid_And_BlankTopography

    retValue = SurferApp.GridData(DataFile:=Data, Algorithm:=gridAlgorithm, _
        ShowReport:=False, OutGrid:=Grid, OutFmt:=srfGridFmtBinary, _
        NumCols:=colCount, NumRows:=rowCount, xMin:=minX, xMax:=maxX, _
        yMin:=minY, yMax:=maxY, KrigType:=srfKrigPoint)
    Doc.Selection.DeselectAll

    If Not isRayTrial Then
        'Blank grid area above topography
        retValue = SurferApp.GridBlank(InGrid:=Grid, BlankFile:=BlankFile, _
            OutGrid:=Grid, OutFmt:=srfGridFmtBinary)
        Doc.Selection.DeselectAll
    End If
End Sub


Sub Determine_YTopCoord
    If Not boreholeSurvey Then
        yTopCoord = maxY
        If labelShotPoints And Not userPlotLimits Then
            yTopCoord = maxY + (maxY - minY)/20.0
        End If
    Else
        yTopCoord = maxY
    End If
End Sub


Sub Setup_MapFrame_Limits_And_Scale ( frame As Object )
    'Setup Limits tab, for map: don't blank out shot labels !
    Determine_YTopCoord

    frame.SetLimits(minX, maxX, minY, yTopCoord)
    If proportionalXYScaling Then
        'Leave default scale and size; works fine
        'frame.xLength = 4
        'frame.yMapPerPU = frame.xMapPerPU
    Else
        Dim xLength As Double
        xLength = 6
        Dim yLength As Double
        yLength = 4
        If userPlotLimits Then
            xLength = xScaleLength
            yLength = yScaleLength
        End If
        Convert_Inch_To_Centimeter xLength
        frame.xLength = xLength

        Convert_Inch_To_Centimeter yLength
        frame.yLength = yLength
    End If    'Setup Scale tab, for map
End Sub


Sub Setup_ColorMap ( ImageMap As Object, _
    adaptDataLimits As Boolean )

    Set ColorMap = ImageMap.ColorMap

    Dim oldSurfer As Boolean
    oldSurfer = ( InStr(SurferApp.Version, "8.") = 1 )
    oldSurfer = oldSurfer Or ( InStr(SurferApp.Version, "7.") = 1 )
    If ( oldSurfer ) Then
        ColorMap.LoadFile(SurferApp.Path+"\samples\rainbow2.clr")
    Else
        ColorMap.LoadFile(SurferApp.Path+"\colorscales\rainbow2.clr")
    End If

    If adaptDataLimits Then
        ColorMap.SetDataLimits(DataMin:=trunc_minZ, DataMax:=trunc_maxZ)
    End If

End Sub


Sub Setup_HillShading ( imageMap As Object )

    Dim isSurfer13 As Boolean
    Dim isSurfer14 As Boolean
    Dim isSurfer15 As Boolean
    Dim isSurfer13OrLater As Boolean

    isSurfer13 = ( InStr(SurferApp.Version, "13.") = 1 )
    isSurfer14 = ( InStr(SurferApp.Version, "14.") = 1 )
    isSurfer15 = ( InStr(SurferApp.Version, "15.") = 1 )
    isSurfer13OrLater = isSurfer13 Or isSurfer14 Or isSurfer15
    If isSurfer13OrLater Then
      imageMap.HillShading = False
    End If

End Sub

Sub Setup_ImageMap_GeneralTab ( imageMap As Object )
    'Setup General tab, for image map
    imageMap.InterpolatePixels = True
    imageMap.ShowColorScale = True
    imageMap.MissingDataColor = srfColorWhite
End Sub

Sub Create_And_Configure_ImageMap

    Set ImageMapFrame = Doc.Shapes.AddImageMap(Grid)
    Set Overlays = ImageMapFrame.Overlays()
    Set ImageMap = Overlays(1)

    Doc.Selection.DeselectAll

    'Setup image map attributes
    Setup_ImageMap_GeneralTab imageMap:=ImageMap

    Setup_ColorMap ImageMap, adaptDataLimits:=True
    Setup_HillShading ImageMap

    Setup_ImageMap_GeneralTab imageMap:=ImageMap

    Doc.Selection.DeselectAll

End Sub

Sub Setup_ContourMap_Levels
    'Setup Levels tab, for contour map
    maxZ_Contour = trunc_maxZ
    If ( ( trunc_maxZ - zContour_Interval ) > zContour_Interval ) Then
        maxZ_Contour = trunc_maxZ - zContour_Interval
    End If

    ContourLevels.AutoGenerate(MinLevel:=zContour_Interval, _
        MaxLevel:=maxZ_Contour, _
        Interval:=zContour_Interval)

    ContourLevels.SetLabelFrequency(FirstIndex:=1, _
        NumberToSet:=1, NumberToSkip:=1)

    Doc.Selection.DeselectAll

    For Each ContourLevel In ContourLevels
        Set LevelLine = ContourLevel.Line
        LevelLine.ForeColor = srfColorBlack40
    Next

    Doc.Selection.DeselectAll

End Sub


Sub Create_And_Configure_ContourMap
    Set ContourMapFrame = Doc.Shapes.AddContourMap(Grid)
    Set Overlays = ContourMapFrame.Overlays()
    Set ContourMap = Overlays(1)
    Set ContourLevels = ContourMap.Levels

    Doc.Selection.DeselectAll

    'Setup contour map attributes
    'Setup General tab, for contour map
    ContourMap.SmoothContours = srfConSmoothMed

    Setup_ContourMap_Levels

End Sub

Sub Setup_Receiver_Symbol ( postMap As Object )

    Dim recvrSize As Double
    If GSCenteredFont Then
        recvrSize = 0.15
    Else
        recvrSize = 0.10
    End If
    Convert_Inch_To_Centimeter recvrSize

    If GSCenteredFont Then
        postMap.BinSymbol(Index:=3).Set = "GS CENTERED"
        postMap.BinSymbol(Index:=3).Index = 48
    Else
        postMap.BinSymbol(Index:=3).Set = "GSI Default Symbols"
        postMap.BinSymbol(Index:=3).Index = 102
    End If
    postMap.BinSymbol(Index:=3).Size = recvrSize
    postMap.BinSymbol(Index:=3).Color = srfColorBlack40

End Sub

Sub Setup_Source_Symbol ( postMap As Object )

    Dim sourceSize As Double
    sourceSize = 0.10
    Convert_Inch_To_Centimeter sourceSize

    postMap.BinSymbol(Index:=2).Set = "GSI Default Symbols"
    postMap.BinSymbol(Index:=2).Index = 21
    postMap.BinSymbol(Index:=2).Size = sourceSize
    postMap.BinSymbol(Index:=2).Color = srfColorRed

End Sub

Sub Setup_Invisible_Symbol ( postMap As Object )

    postMap.BinSymbol(Index:=1).Set = "GSI Default Symbols"
    postMap.BinSymbol(Index:=1).Index = 115
    postMap.BinSymbol(Index:=1).Size = 0.001

End Sub

Sub Create_And_Configure_ShotPostMap ( postMapFrame As Object, _
       postMap As Object )

    Set postMapFrame = Doc.Shapes.AddClassedPostMap(ShotDataFile, 1,2,3,4)
    Set postMap = postMapFrame.Overlays(1)

    postMap.NumClasses = 3

    Setup_Invisible_Symbol postMap:=postMap
    Setup_Source_Symbol postMap:=postMap
    Setup_Receiver_Symbol postMap:=postMap

    Dim Limits(6) As Double
    Limits(0) = 0: Limits(1) = 0.001
    Limits(2) = 1: Limits(3) = 1.001
    Limits(4) = 2: Limits(5) = 2.001
    postMap.SetBinLimits(Limits:=Limits)

    postMap.LabCol = 4
    If boreholeSurvey And Not horizontalHole Then
        postMap.LabelPos = srfPostPosRight
    Else
        postMap.LabelPos = srfPostPosAbove
    End If
End Sub

Sub Overlay_Maps
    Doc.Selection.DeselectAll
    ImageMapFrame.Selected = True
    If contourGrid Then
        ContourMapFrame.Selected = True
    End If
    If postShotPoints Or postReceivers Then
        ShotPostMapFrame.Selected = True
    End If

    If ( Not contourGrid And Not postShotPoints _
         And Not postReceivers ) Then
        Set OverlayMapFrame = ImageMapFrame
    Else
        Set OverlayMapFrame = Doc.Selection.OverlayMaps
    End If

    Setup_MapFrame_Limits_And_Scale(OverlayMapFrame)

    Doc.Selection.DeselectAll
End Sub

Sub Setup_Title_XYCoords_InPageUnits ( document As Object, _
    title As String, _
    xTitle As Double, _
    yTitle As Double )

    Dim PageSetup As Object
    Set PageSetup = document.PageSetup

    If verticalPlotTitle Then
        xTitle = 1.0 - Len(title)/50
        yTitle = 5.5
    ElseIf PageSetup.Orientation = srfLandscape Then
        xTitle = 2.4
        yTitle = 6.55
    Else
        xTitle = 1.0
        yTitle = 7.8
    End If

    Convert_Inch_To_Centimeter xTitle
    Convert_Inch_To_Centimeter yTitle
End Sub

Sub Add_PlotTitle_ToDocument ( document As Object, _
    title As String )

    Dim xTitle As Double
    Dim yTitle As Double

    Setup_Title_XYCoords_InPageUnits document, title, xTitle, yTitle

    Dim TitleText As Object
    Set TitleText = document.Shapes.AddText(x:=xTitle, y:=yTitle, Text:=title)

    If verticalPlotTitle Then
        TitleText.Rotation = -90
    End If

    document.Selection.DeselectAll
End Sub

Sub Show_And_Save_Overlay
    'Add title to plot
    Add_PlotTitle_ToDocument Doc, PlotTitle

    'Zoom to full display size
    Plotwindow.WindowState = srfWindowStateMaximized
    Plotwindow.Zoom(srfZoomFitToWindow)

    'Enable ScreenUpdating, AutoRedraw to update the plot window
    SurferApp.ScreenUpdating = True
    Plotwindow.AutoRedraw = True

    'Save annotated image map to .srf file : SaveAs is not available in free Demo version
    If Not isSrfTrial Then
        Doc.SaveAs(FileName:=SrfFile)
    End If

End Sub

Sub Signal_StartOfImaging_ToRayfract
    Dim StartString As String

    'Wait 1 ' give time to Windows to display Scripter window

    StartString = "Automatic imaging of the .CSV data with Surfer has started."
    Open "AUTODLTA.RUN" For Output As #1
    Write #1, StartString
    Close #1

    Debug.Print "Start flag file AUTODLTA.RUN written !"

End Sub

Sub Signal_CompletionOfImaging_ToRayfract

    Dim ResultString As String

    'Give Surfer enough time to completely draw and zoom output
    Wait 5

    ResultString = "The .CSV data has been gridded and imaged successfully."
    Open End_FlagFile For Output As #1
    Write #1, ResultString
    Close #1

    Debug.Print "End_FlagFile written !"
    Debug.Print ""

    'Disable error handling as for SurferApp Create
    'On Error Resume Next 'Turn off error reporting
    SurferApp.WindowState = srfWindowStateMinimized
    'AppActivate Rayfract_AppTitle

End Sub

Sub Minimize_Scripter

    'SendKeys "%F{Left}n", 1
    'SendKeys "{Left}"
    'SendKeys "n"

End Sub

Sub Configure_Debugging

    debugScript = False
    Debug.Print ""

End Sub


Sub Main

    Configure_Debugging

    Signal_StartOfImaging_ToRayfract

    'Minimize_Scripter

    Init_Global_Vars
    Init_Vars_From_ParFile
    Init_FileNames_From_Data
    Init_GriddingMethod_FromFile
    Init_GridAlgorithm_ForMethod

    Get_Surfer_Instance

    If Not griddedAlready Then
        CreateGrid_And_BlankTopography
    End If

    Create_And_Configure_ImageMap
    If contourGrid Then
        Create_And_Configure_ContourMap
    End If
    If postShotPoints Or postReceivers Then
        Create_And_Configure_ShotPostMap ShotPostMapFrame, _
            ShotPostMap
    End If

    Overlay_Maps

    Show_And_Save_Overlay

    Signal_CompletionOfImaging_ToRayfract

End Sub
